@@ -23,6 +23,7 @@ from .orm import (
     get_column_key,
     get_columns,
     get_declarative_base,
+    get_hybrid_properties,
     get_mapper,
     get_primary_keys,
     get_tables,
@@ -46,6 +47,7 @@ __all__ = (
     'get_bind',
     'get_columns',
     'get_declarative_base',
+    'get_hybrid_properties',
     'get_mapper',
     'get_primary_keys',
     'get_referencing_foreign_keys',
